@@ -36,7 +36,10 @@ sub out_gdl
     {
         $glyph = $self->{'glyphs'}[$i];
         $fh->print("$glyph->{'name'} = ");
-        $fh->print("glyphid($i)");
+        if ($opts{'-psnames'} && $glyph->{'PSName'})
+        { $fh->print("postscript(\"$glyph->{'PSName'}\")"); }
+        else
+        { $fh->print("glyphid($i)"); }
 
         my ($ytop) = $f->{'hhea'}->read->{'Ascender'};
         my ($adv) = $f->{'hmtx'}->read->{'advance'}[$i];
@@ -52,16 +55,16 @@ sub out_gdl
 
                 if ($opts{'-split_ligs'})
                 {
-                    if (defined $glyph->{'comps'}{$pl})
-                    { $glyph->{'comps'}{$pl}[3] = $pt->{'x'}; }
+                    if (defined $glyph->{'compunds'}{$pl})
+                    { $glyph->{'compounds'}{$pl}[3] = $pt->{'x'}; }
                     else
-                    { $glyph->{'comps'}{$pl} = [0, 0, $pt->{'x'}, $ytop]; }
+                    { $glyph->{'compounds'}{$pl} = [0, 0, $pt->{'x'}, $ytop]; }
                     if ($pr)
                     {
-                        if (defined $glyph->{'comps'}{$pr})
-                        { $glyph->{'comps'}{$pr}[0] = $pt->{'x'}; }
+                        if (defined $glyph->{'compounds'}{$pr})
+                        { $glyph->{'compounds'}{$pr}[0] = $pt->{'x'}; }
                         else
-                        { $glyph->{'comps'}{$pr} = [$pt->{'x'}, 0, $adv, $ytop]; }
+                        { $glyph->{'compounds'}{$pr} = [$pt->{'x'}, 0, $adv, $ytop]; }
                     }
                 }
                 next;
@@ -82,27 +85,27 @@ sub out_gdl
             {
                 my ($n) = $k;
                 $n =~ s/^component\.//o;
-                $glyph->{'comps'}{$n} = [0, 0, $glyph->{'props'}{$k}, $ytop];
+                $glyph->{'compounds'}{$n} = [0, 0, $glyph->{'props'}{$k}, $ytop];
             }
-            foreach $k (sort {$glyph->{'comps'}{$a}[2] <=> $glyph->{'comps'}{$b}[2]} keys %{$glyph->{'comps'}})
+            foreach $k (sort {$glyph->{'compounds'}{$a}[2] <=> $glyph->{'compounds'}{$b}[2]} keys %{$glyph->{'compounds'}})
             {
-                $glyph->{'comps'}{$k} = [$oldx, 0, $glyph->{'comps'}{$k}[2], $glyph->{'comps'}{$k}[3]];
-                $oldx = $glyph->{'comps'}{$k}[2];
+                $glyph->{'compounds'}{$k} = [$oldx, 0, $glyph->{'compounds'}{$k}[2], $glyph->{'compounds'}{$k}[3]];
+                $oldx = $glyph->{'compounds'}{$k}[2];
                 $min = $k if ($k > $min);
             }
-            if (scalar %{$glyph->{'comps'}} && $oldx < $adv)
+            if (scalar %{$glyph->{'compounds'}} && $oldx < $adv)
             {
                 my ($maxx) = $f->{'loca'}->read->{'glyphs'}[$i]{'xMax'};
                 if ($oldx < $maxx)          # only add magic compound if some outline not covered
                 {
                     $min++;
-                    $glyph->{'comps'}{$min} = [$oldx, 0, $adv, $ytop];
+                    $glyph->{'compounds'}{$min} = [$oldx, 0, $adv, $ytop];
                 }
             }
         }
-        foreach $k (keys %{$glyph->{'comps'}})
+        foreach $k (keys %{$glyph->{'compounds'}})
         {
-            $fh->print("${sep}component.$k = box(" . join(", ", map {"${_}m"} @{$glyph->{'comps'}{$k}}) . ")");
+            $fh->print("${sep}component.$k = box(" . join(", ", map {"${_}m"} @{$glyph->{'compounds'}{$k}}) . ")");
             $sep = '; ';
         }
         foreach $k (keys %{$glyph->{'props'}})
@@ -182,7 +185,7 @@ sub out_classes
 
     foreach $cl (sort {classcmp($a, $b)} keys %{$ligclasses})
     {
-        $fh->print("cl$cl = ($glyphs->[$ligclasses->{$cl}[0]]{'name'}");
+        $fh->print("clig$cl = ($glyphs->[$ligclasses->{$cl}[0]]{'name'}");
         for ($i = 1; $i <= $#{$ligclasses->{$cl}}; $i++)
         { $fh->print($i % 8 ? ", $glyphs->[$ligclasses->{$cl}[$i]]{'name'}" : ",\n    $glyphs->[$ligclasses->{$cl}[$i]]{'name'}"); }
         $fh->print(");\n\n");
@@ -221,12 +224,18 @@ sub make_name
     my ($self, $gname, $uni, $glyph) = @_;
     $gname =~ s{/.*$}{}o;
     $gname =~ s/\.(.)/'_'.lc($1)/oge;
-    if ($gname =~ m/^u(?:ni)?(?:[0-9A-Fa-f]{4,6})/o)
+    if ($gname =~ m/^u(?:[0-9A-Fa-f]{4,6})/oi)
     { 
         $gname = "g" . lc($gname);
-        $gname =~ s/^gu(?:ni)?/g/o;
+        $gname =~ s/^gu/g/o;
         $gname =~ s/_u/_/og;
     }
+    elsif ($gname =~ s/^uni(?=[0-9A-Fa-f]{4})//oi)
+    {
+        my (@nums) = $gname =~ m/([0-9A-Fa-f]{4})/og;
+        $gname =~ s/[0-9A-Fa-f]{4}//og;
+        $gname = 'g_' . join('_', @nums) . $gname;
+    }
     else
     {
         $gname = "g_" . $gname;
@@ -247,8 +256,8 @@ sub make_point
         my ($adv) = $self->{'font'}{'hmtx'}->read->{'advances'}[$glyph->{'gnum'}];
         my ($split) = $glyph->{'points'}{$p}{'x'};
 
-        $glyph->{'comps'}{$left} = [0, $bot, $split, $top];
-        $glyph->{'comps'}{$right} = [$split, $bot, $adv, $top];
+        $glyph->{'compounds'}{$left} = [0, $bot, $split, $top];
+        $glyph->{'compounds'}{$right} = [$split, $bot, $adv, $top];
         return undef;
     }
 
@@ -311,7 +320,7 @@ sub lig_rules
         my ($gname) = $self->{'glyphs'}[$gnum]{'name'};
         my ($compstr);
 
-        if ($self->{'glyphs'}[$ligclasses->{$c}[0]]{'comps'}{'0'})
+        if ($self->{'glyphs'}[$ligclasses->{$c}[0]]{'compounds'}{'0'})
         { $compstr = ' {component.0.reference = @1; component.1.reference = @2}'; }
 
         if ($type eq 'first')
